@@ -1,4 +1,4 @@
-rimle <- function(data, G, initial = NULL, logicd = NULL, npr.max = 0.5, erc = 50, 
+rimle <- function(data, G, initial = NULL, logicd = NULL, npr.max = 0.5, erc = 20, 
   iter.max = 500, tol = 1e-06) {
   if (is.vector(data)) {
     data <- matrix(data, ncol = 1)
@@ -7,7 +7,7 @@ rimle <- function(data, G, initial = NULL, logicd = NULL, npr.max = 0.5, erc = 5
     data <- data.matrix(data)
   }
   if (!is.numeric(data)) {
-    stop("\"data\" must be numeric.")
+    stop("\n'data'must be numeric.\n\n")
   }
   if (!is.null(initial) & {
     !is.numeric(initial) | any(initial < 0) | {
@@ -30,14 +30,17 @@ rimle <- function(data, G, initial = NULL, logicd = NULL, npr.max = 0.5, erc = 5
   }) {
     stop("\"logicd\" must be numeric of length=1.")
   }
-  if (npr.max <= 0 | npr.max >= 1) {
-    stop("\"npr.max\" must belog to the interval (0,1). Tipically npr.max<=0.5.")
+  if (npr.max == 0) {
+    logicd <- -Inf
+  }
+  else if (npr.max < 0 | npr.max >= 1) {
+    stop("\"npr.max\" must belog to the interval [0,1). Tipically npr.max<=0.5.")
   }
   if (erc < 1) {
     stop("\"ecr\" must be larger or equal to 1.")
   }
-  if (iter.max < 2) {
-    stop("\"iter.max\" must be an integer larger or equal to 2.")
+  if (iter.max < 1) {
+    stop("\"iter.max\" must be an integer larger or equal to 1.")
   }
   if (tol < 0) {
     stop("\"tol\" must be positive.")
@@ -47,18 +50,17 @@ rimle <- function(data, G, initial = NULL, logicd = NULL, npr.max = 0.5, erc = 5
   }
   else {
     initial <- .Cluster2Assign(initial)
-  }
-  G <- ncol(initial) - 1
-  nj <- rep(0, times = G)
-  for (j in 1:G) {
-    nj[j] <- .CountUniqueRows(data[initial[, 1 + j] == 1, ])
-  }
-  if (any(nj < 2)) {
-    Suggest <- paste("initial = sample(0:", G, ",  size=", nrow(data), ", replace=TRUE)", 
-      sep = "")
-    StopMsg <- paste("\n\nSome of the initial clusters contain less then 2 distinct points. Initial parameters cannot be computed. Try a random initial partition setting: \n\n", 
-      Suggest, sep = "")
-    stop(StopMsg)
+    G <- ncol(initial) - 1
+    nj <- rep(0, times = G)
+    for (j in 1:G) {
+      nj[j] <- .CountUniqueRows(data[initial[, 1 + j] == 1, ])
+    }
+    if (any(nj < 2)) {
+      StopMsg <- paste("Some of the initial clusters contain less then 2 distinct points. Initial parameters cannot be computed. See details in help(InitClust) and try a different initial partition.\n\n", 
+        sep = "")
+      cat("\n")
+      stop(StopMsg)
+    }
   }
   if (is.null(logicd)) {
     N <- nrow(data)
@@ -91,8 +93,25 @@ rimle <- function(data, G, initial = NULL, logicd = NULL, npr.max = 0.5, erc = 5
     }
     logicd <- min(logicds)
   }
+  nn <- .CountUniqueRows(data)
+  if (logicd == -Inf) {
+    if (nn <= G) {
+      cat("\n")
+      StopMsg <- paste0("There are m = ", nn, " distinct data points in the data set. With logicd = -Inf, RIMLE existence requires m > G. Try to decrease 'G'.\n\n")
+      stop(StopMsg)
+    }
+  }
+  if (logicd > -Inf) {
+    if (nn <= {
+      G + ceiling(nrow(data) * npr.max)
+    }) {
+      cat("\n")
+      StopMsg <- paste0("There are m = ", nn, " distinct data points in the data set. With  logicd > -Inf, RIMLE existence requires m > G + ceiling(nrow(data)*npr.max). Try to vary 'npr.max', 'logicd', and/or 'G'. \n\n")
+      stop(StopMsg)
+    }
+  }
   ans <- .ECM(data = data, initial = initial, logicd = logicd, npr.max = npr.max, 
-    erc = erc, iter.max = iter.max, tol = tol, grid.operation = FALSE)
+    erc = erc, beta = 0, iter.max = iter.max, tol = tol, grid.operation = FALSE)
   class(ans) <- "rimle"
   return(ans)
 }
